@@ -4,7 +4,7 @@
 modname = 'bootstrap'
 distname = 'cubicweb-bootstrap'
 
-numversion = (0, 4, 1)
+numversion = (0, 4, 2)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -42,7 +42,10 @@ data_files = [
 # check for possible extended cube layout
 for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema',
               'data',
-              'data/css', 'data/img', 'data/js',
+              'data/css',
+              'data/img',
+              'data/js',
+              'data/fonts',
               'wdoc', 'i18n', 'migration'):
     if isdir(dname):
         data_files.append([join(THIS_CUBE_DIR, dname), listdir(dname)])
