@@ -28,7 +28,7 @@ basetemplates.LogForm.form_buttons = [
 basetemplates.LogForm.form_renderer_id = 'modal-form-renderer'
 
 @monkeypatch(basetemplates.LogFormView)
-def call(self, id, klass, title=True, showmessage=True):
+def call(self, id, klass, title=True, showmessage=True, showonload=True):
     w = self.w
     if not (showmessage or self._cw.message):
         showmessage = False
@@ -39,14 +39,15 @@ def call(self, id, klass, title=True, showmessage=True):
             stitle = xml_escape(stitle)
     config = self._cw.vreg.config
     if config['auth-mode'] != 'http':
-        self.login_form(id, "loginModal", stitle, showmessage) # Cookie authentication
+        self.login_form(id, "loginModal", stitle,
+                        showmessage, showonload) # Cookie authentication
     if self._cw.https and config.anonymous_user()[0]:
         path = xml_escape(config['base-url'] + self._cw.relative_path())
         w(u'<div class="loginMessage alert"><a href="%s">%s</a></div>\n'
           % (path, self._cw._('No account? Try public access at %s') % path))
 
 @monkeypatch(basetemplates.LogFormView)
-def login_form(self, id, modal_id, title, showmessage):
+def login_form(self, id, modal_id, title, showmessage, showonload):
     cw = self._cw
     form = cw.vreg['forms'].select('logform', cw)
     if cw.vreg.config['allow-email-login']:
@@ -56,5 +57,7 @@ def login_form(self, id, modal_id, title, showmessage):
     form.field_by_name('__login').label = label
     form.render(w=self.w, table_class='', display_progress_div=False,
                 modal_id=modal_id,
-                title=title, showmessage=showmessage)
+                title=title,
+                showmessage=showmessage,
+                showonload=showonload)
     cw.html_headers.add_onload('jQuery("#__login:visible").focus()')
