@@ -11,9 +11,9 @@ from logilab.common.decorators import monkeypatch
 
 from cubicweb.web.views import baseviews
 
-
+baseviews.ListView.listtag = 'ul'
 @monkeypatch(baseviews.ListView)
-def call(self, klass=None, title=None, subvid=None, listid=None, **kwargs):
+def call(self, klass='list-striped', title=None, subvid=None, listid=None, **kwargs):
     """display a list of entities by calling their <item_vid> view
 
     :param listid: the DOM id to use for the root element
@@ -27,24 +27,33 @@ def call(self, klass=None, title=None, subvid=None, listid=None, **kwargs):
     klass = u'' if klass is None else u' class="%s"' % klass
     if title:
         self.w(u'<div%s%s><h4>%s</h4>\n' % (listid, klass, title))
-        self.w(u'<ul>\n')
+        self.w(u'<%s class="%s">\n' % (self.listtag, klass))
     else:
-        self.w(u'<ul%s%s>\n' % (listid, klass))
+        self.w(u'<%s%s%s>\n' % (self.listtag, listid, klass))
     for i in xrange(self.cw_rset.rowcount):
         self.cell_call(row=i, col=0, vid=subvid, **kwargs)
-    self.w(u'</ul>\n')
+    self.w(u'</%s>\n' % self.listtag)
     if title:
         self.w(u'</div>\n')
 
+@monkeypatch(baseviews.ListView)
+def cell_call(self, row, col=0, vid=None, **kwargs):
+    self.w(u'<li class="%s">' %  (u'odd' if row%2 else u'even'))
+    self.wview(self.item_vid, self.cw_rset, row=row, col=col, vid=vid, **kwargs)
+    self.w(u'</li>\n')
+
+
+
 @monkeypatch(baseviews.SameETypeListView)
-def call(self, **kwargs):
+def call(self,  klass='list-striped', **kwargs):
     w = self.w
     showtitle = kwargs.pop('showtitle', not 'vtitle' in self._cw.form)
     if showtitle:
         w(u'<h1>%s</h1>' % self.title)
-    w(u'<ul class="list-unstyled">\n')
+    klass = u'' if klass is None else u' class="%s"' % klass
+    w(u'<ul%s>\n' % klass)
     for i in xrange(len(self.cw_rset)):
-        w(u'<li>')
+        w(u'<li class="%s">' %  (u'odd' if i%2 else u'even'))
         self._cw.view(self.item_vid, self.cw_rset, row=i, col=0, w=w)
         w(u'</li>')
     w(u'</ul>\n')
