@@ -20,21 +20,16 @@ from cubes.bootstrap.views.htmlwidgets import (MainToolbarBoxMenu,
                                                bwcompatible_render_item)
 
 boxes.SearchBox.formdef = (
-    u'<div id="search-box">'
-    u'<form action="%(action)s">'
+    u'<div id="search-box">\n'
+    u'<form action="%(action)s">\n'
     u'<input id="norql" type="text" accesskey="q" tabindex="%(tabindex1)s"'
     u'       title="search text" value="%(value)s" name="rql"'
-    u'       class="search-query" placeholder="%(searchlabel)s"/>'
+    u'       class="search-query" placeholder="%(searchlabel)s"/>\n'
     u'       <input type="hidden" name="__fromsearchbox" '
-    u'              value="1" />'
+    u'              value="1" />\n'
     u'       <input type="hidden" name="subvid" '
-    u'value="tsearch" />'
-    #FIXME this commented html code is left because the string
-    #replacement would fail unless the render method is modified
-    #also
-    u'<!--input tabindex="%(tabindex2)s" type="submit" id="rqlboxsubmit"'
-    u'    class="rqlsubmit" value="" /-->'
-    u'</form></div>')
+    u'value="tsearch" />\n'
+    u'</form></div>\n')
 
 @monkeypatch(boxes.SearchBox)
 def render_body(self, w):
@@ -46,7 +41,6 @@ def render_body(self, w):
     w(self.formdef % {'action': self._cw.build_url('view'),
                       'tabindex1': self._cw.next_tabindex(),
                       'value': xml_escape(rql),
-                      'tabindex2': self._cw.next_tabindex(),
                       'searchlabel': self._cw._('Search')})
 
 
