@@ -20,7 +20,7 @@ def render(self, w, **kwargs):
         entity = self.cw_extra_kwargs['entity']
     except KeyError:
         entity = self.cw_rset.get_entity(0, 0)
-    adapter = ibreadcrumbs.ibreadcrumb_adapter(entity)
+    adapter = entity.cw_adapt_to('IBreadCrumbs')
     view = self.cw_extra_kwargs.get('view')
     path = adapter.breadcrumbs(view)
     if path:
